@@ -1,10 +1,10 @@
-# ml
-
+# data
 from . import data
 # classification
-from . import logistic_regression
-from . import support_vector_classifier
+from . import classification
 # regression
 from . import linear_regression
 # clustering
 from . import clustering
+# association
+from . import association
